@@ -1,11 +1,11 @@
-# @(#)$Id: IO.pm 420 2012-12-12 23:23:04Z pjf $
+# @(#)$Id: IO.pm 421 2012-12-14 17:44:12Z pjf $
 
 package File::DataClass::IO;
 
 use strict;
 use namespace::clean -except => 'meta';
 use overload '""' => sub { shift->pathname }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 420 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 421 $ =~ /\d+/gmx );
 
 use Moose;
 use File::DataClass::Constants;
@@ -283,9 +283,9 @@ sub clear {
 }
 
 sub close {
-   my $self = shift; $self->is_open or return $self;
+   my $self = shift; $self->is_open or return $self; my $osname = lc $OSNAME;
 
-   if ($OSNAME eq EVIL or $OSNAME eq CYGWIN) { $self->_close_and_rename }
+   if ($osname eq EVIL or $osname eq CYGWIN) { $self->_close_and_rename }
    else { $self->_rename_and_close }
 
    $self->io_handle( undef );
@@ -294,21 +294,23 @@ sub close {
    return $self;
 }
 
-sub _close_and_rename {
-   my $self = shift; $self->unlock;
+sub _close_and_rename { # This creates a race condition
+   warn "CPANTesting - Winshite detected\n";
+   my $self = shift; $self->unlock; my $handle = $self->io_handle;
 
-   my $handle = $self->io_handle; $handle and undef $handle;
+   $handle and $handle->close; $handle and undef $handle;
 
    $self->_atomic and $self->_rename_atomic;
+
    return $self;
 }
 
-sub _rename_and_close {
-   my $self = shift;
+sub _rename_and_close { # This does not create a race condition
+   my $self = shift; $self->_atomic and $self->_rename_atomic; $self->unlock;
 
-   $self->_atomic and $self->_rename_atomic; $self->unlock;
+   my $handle = $self->io_handle; $handle and $handle->close;
 
-   my $handle = $self->io_handle; $handle and undef $handle;
+   $handle and undef $handle;
 
    return $self;
 }
@@ -740,14 +742,17 @@ sub relative {
 }
 
 sub _rename_atomic {
-   my $self = shift; my $path = $self->_get_atomic_path;
+   my $self = shift; my $path = $self->_get_atomic_path or return;
 
-   if ($path and -f $path) {
-      File::Copy::move( $path, $self->name )
-         or $self->_throw( error => 'Cannot rename [_1] to [_2]: [_3]',
-                           args  => [ $path, $self->name, $ERRNO ] );
+   -f $path or return; File::Copy::move( $path, $self->name ) and return;
+
+   my $osname = lc $OSNAME; unless ($osname eq EVIL or $osname eq CYGWIN) {
+      $self->_throw( error => 'Cannot rename [_1] to [_2]: [_3]',
+                     args  => [ $path, $self->name, $ERRNO ] );
    }
 
+   # Try this instead on Winshite but fail silently
+   File::Copy::copy( $path, $self->name ); eval { unlink $path };
    return;
 }
 
@@ -762,7 +767,7 @@ sub rmtree {
 sub seek {
    my ($self, @rest) = @_;
 
-   $self->is_open or $self->assert_open( $OSNAME eq EVIL ? q(r) : q(r+) );
+   $self->is_open or $self->assert_open( lc $OSNAME eq EVIL ? q(r) : q(r+) );
 
    my @sunk = $self->io_handle->seek( @rest ); $self->error_check;
 
@@ -950,7 +955,7 @@ File::DataClass::IO - Better IO syntax
 
 =head1 Version
 
-0.13.$Revision: 420 $
+0.13.$Revision: 421 $
 
 =head1 Synopsis
 
